@@ -76,7 +76,7 @@ class AMQPData(GeneralData):
                 self.channel.queue_bind(self.queue_name, self.exchange, self.routing_key)
             else:
                 self.queue_default = self.channel.queue_declare("",exclusive=True)
-                self.queue_name =  self.queue_default.method.name
+                self.queue_name =  self.queue_default.method.queue
                 rprint("Queue name from SOURCE", self.queue_name)
                 self.channel.queue_bind(self.queue_name, exchange=self.exchange)
         except Exception as e:
